Calculate confidence intervals for list of boot objects
Source: R/get_bootstrap_ci.R
get_bootstrap_ci.RdThis function calculates confidence intervals for a list of objects of class
"boot" per year into a dataframe containing all required summaries.
Arguments
- bootstrap_list
A list of objects of class
"boot"per year.- temporal_list_name
(Optional) The temporal list names of
bootstrap_list(e.g., year, month ...) containing time point values. Defaultyear.- ...
Additional argument to be passed to the
boot::boot.ci()function.
Value
The returned value is a dataframe containing the time point,
the type of interval (int_type), the lower limit of the confidence
interval (ll), the upper limit of the confidence interval (ul), the
bootstrap estimate (est_boot), the bootstrap standard error (se_boot),
the bootstrap bias (bias_boot), and the confidence level of the
intervals (conf_level).